myplot: myplot

Description Usage Arguments Details Value Examples

View source: R/myplot.R

Description

Make a function that produces heights for inputs "x"

Usage

1
myplot(x)

Arguments

x

a vector of values

Details

This is a function created in the Math4753 package that when given the spruce.lm data set it outputs the height in a plot

Value

a series of points used to calculate a curve

Examples

1
2
curve(myplot, lwd=2, col="steelblue",add=TRUE)
#

lukedlw/math4753ward0018 documentation built on April 28, 2020, 6:07 a.m.