Description Usage Arguments Details Value Examples
Make a function that produces heights for inputs "x"
1 | myplot(x)
|
x |
a vector of values |
This is a function created in the Math4753 package that when given the spruce.lm data set it outputs the height in a plot
a series of points used to calculate a curve
1 2 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.